C-*-FORTRAN-*-
C +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C +               ALEPH FERMIOPHOBIC HIGGS SEARCHES (V1.1)        +
C +    USING DATA FROM YEAR 1991 UP TO 2000 WITH L=220.7 pb-1     +
C +                                A. TILQUIN  6/02/2001          +
C +---------------------------------------------------------------+
C + Version 1.1                                                   +
C +    Cut analysis, valid from mh = 1 GeV up to 130. GeV         +
C +    Reference paper CERN-EP/2000-083                           +     
C +      The background shape is integrated over all energies     +
C +                and all Z decay channel                        +
C +      Signal shape is integrated over all Z decay channel      +
C +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C    Following include are needed:
C        a_zhgg_91_210_decl.inc : general parameter definition
C                            Needed in main routine and in
C                            a_zhgg_ext_func.F
C        a_zhgg_ext_main.inc : External declaration of global functions
C                            to compute efficiencies, signal
C                            and background shape.
C                            Needed in general main routine
C        a_zhgg_ext_shape.inc: External declaration of specific
C                            functions to compute efficiencies, signal
C                            and background shape.
C                            Needed in a_zhgg_ext_func.F
C        a_zhgg_ext_func.F: External fortran functions including
C                           the sigmoid needed by pawmlp functions.
C        a_zhgg_candid.inc: Candidates declaration. Needed by 
C                           a_zhgg_ext_func.F  
C
C--  
C                   Main part
C--
      switch = .true.
      dosyst = .true.
      subbg = .false.
      if (switch) then
        do iener =  1,a_maxnener
          if ( iener.LE.15 ) then
C
C              1 channel from 88 up to 189 GeV
C              Signal resolution is identical for all
C              energies. Background shape is summed over
C              all energies
C
            if ( iener.EQ.1 ) then
C                  Init
              nchan = nchan + 1
              channame(nchan) = 'ALEPH 91-189 GeV ZH->ffgg'
              ratech = 0.
            endif
C                efficiency in %
            ratech = ratech + xsec(1,iener)*bhgaga*
     &             a_zhgg_eff_88_210(mh,REAL(a_hzgg_gsqrts(iener)))*
     &             a_hzgg_glumi(iener)/100.
            if ( iener.eq.15 ) then
C                 Fill histo
              nbinsint = 100
              xl = 1.
              xu = 130.
C                      signal shape
              call ascreate2F(xl,xu,nbinsint,A_ZHGG_SIG_SHAPE,
     &                      mh,a_hzgg_gsqrts(iener),sighist)
              call ahistscal1(nbinsint,sighist,sig(nbins+1),ratech)
C                      syst on signal
              nerrch(nchan) = 1
              sysname(1,nchan) = 'Y2K-ALLSYST-ZHGG'
C                 Relative error on signal efficiency = 5.2%
              if ( ratech.ne.0 ) then
                dsig(1,nchan) = (ratech*0.052)/ratech
              else
                dsig(1,nchan) = 0.
              endif
C                      Background shape
              call abhcreateB(xl,xu,nbinsint,a_zhgg_bkg_mass,
     &                  a_zhgg_bkg_n,0,0,a_hzgg_gsqrts(iener),
     &                  backw(nbins+1))
C                      No backround substraction
              call vzero(backg(nbins+1),nbinsint)
              dback(1,nchan) = 0.0
C                      Nb candidates
              nacand = A_ZHGG_NUMCAND(a_hzgg_gsqrts(iener))
              IF ( nacand.NE.0 ) THEN
                DO i = 1,nacand
                  candmass = A_ZHGG_MASS_CAND(a_hzgg_gsqrts(iener),i) 
                  call abin1(candmass,xl,xu,nbinsint,ibin)
                  if (ibin.gt.0.and.ibin.le.nbinsint) then
                     ncand(nbins+ibin) = ncand(nbins+ibin) + 1
                  endif
                ENDDO
              ENDIF
              ifirst(nchan) = nbins + 1
              nbins = nbins + nbinsint
            endif
          elseif ( iener.LE.35 ) then
C
C              Higher energies
C
          nchan = nchan + 1
          IF ( iener.EQ.16 ) channame(nchan)='ALEPH 192 GeV ZH->ffgg'
          IF ( iener.EQ.17 ) channame(nchan)='ALEPH 196 GeV ZH->ffgg'
          IF ( iener.EQ.18 ) channame(nchan)='ALEPH 200 GeV ZH->ffgg'
          IF ( iener.EQ.19 ) channame(nchan)='ALEPH 202 GeV ZH->ffgg'
          IF ( iener.EQ.20 ) channame(nchan)='ALEPH 202.5 GeV ZH->ffgg'
          IF ( iener.EQ.21 ) channame(nchan)='ALEPH 203. GeV ZH->ffgg'
          IF ( iener.EQ.22 ) channame(nchan)='ALEPH 203.5 GeV ZH->ffgg'
          IF ( iener.EQ.23 ) channame(nchan)='ALEPH 204. GeV ZH->ffgg'
          IF ( iener.EQ.24 ) channame(nchan)='ALEPH 204.5 GeV ZH->ffgg'
          IF ( iener.EQ.25 ) channame(nchan)='ALEPH 205. GeV ZH->ffgg'
          IF ( iener.EQ.26 ) channame(nchan)='ALEPH 205.5 GeV ZH->ffgg'
          IF ( iener.EQ.27 ) channame(nchan)='ALEPH 206. GeV ZH->ffgg'
          IF ( iener.EQ.28 ) channame(nchan)='ALEPH 206.5 GeV ZH->ffgg'
          IF ( iener.EQ.29 ) channame(nchan)='ALEPH 207. GeV ZH->ffgg'
          IF ( iener.EQ.30 ) channame(nchan)='ALEPH 207.5 GeV ZH->ffgg'
          IF ( iener.EQ.31 ) channame(nchan)='ALEPH 208. GeV ZH->ffgg'
          IF ( iener.EQ.32 ) channame(nchan)='ALEPH 208.5 GeV ZH->ffgg'
          IF ( iener.EQ.33 ) channame(nchan)='ALEPH 209. GeV ZH->ffgg'
          IF ( iener.EQ.34 ) channame(nchan)='ALEPH 209.5 GeV ZH->ffgg'
          IF ( iener.EQ.35 ) channame(nchan)='ALEPH 210. GeV ZH->ffgg'
c
c
C                   efficiency in %
            ratech = xsec(1,iener)*bhgaga*
     &             a_zhgg_eff_88_210(mh,real(a_hzgg_gsqrts(iener)))*
     &             a_hzgg_glumi(iener)/100.
C                 Fill histo
            nbinsint = 100
            xl = 1.
            xu = 140.
C                      signal shape
            call ascreate2F(xl,xu,nbinsint,A_ZHGG_SIG_SHAPE,
     &                      mh,a_hzgg_gsqrts(iener),sighist)
            call ahistscal1(nbinsint,sighist,sig(nbins+1),ratech)
C                      syst on signal
            nerrch(nchan) = 1
          IF ( iener.EQ.16 ) sysname(1,nchan)='AL-ZHGG-192-SYST'
          IF ( iener.EQ.17 ) sysname(1,nchan)='AL-ZHGG-196-SYST'
          IF ( iener.EQ.18 ) sysname(1,nchan)='AL-ZHGG-200-SYST'
          IF ( iener.EQ.19 ) sysname(1,nchan)='AL-ZHGG-202-SYST'
          IF ( iener.EQ.20 ) sysname(1,nchan)='AL-ZHGG-202.5-SYST'
          IF ( iener.EQ.21 ) sysname(1,nchan)='AL-ZHGG-203.-SYST'
          IF ( iener.EQ.22 ) sysname(1,nchan)='AL-ZHGG-203.5-SYST'
          IF ( iener.EQ.23 ) sysname(1,nchan)='AL-ZHGG-204.-SYST'
          IF ( iener.EQ.24 ) sysname(1,nchan)='AL-ZHGG-204.5-SYST'
          IF ( iener.EQ.25 ) sysname(1,nchan)='AL-ZHGG-205.-SYST'
          IF ( iener.EQ.26 ) sysname(1,nchan)='AL-ZHGG-205.5-SYST'
          IF ( iener.EQ.27 ) sysname(1,nchan)='AL-ZHGG-206.-SYST'
          IF ( iener.EQ.28 ) sysname(1,nchan)='AL-ZHGG-206.5-SYST'
          IF ( iener.EQ.29 ) sysname(1,nchan)='AL-ZHGG-207.-SYST'
          IF ( iener.EQ.30 ) sysname(1,nchan)='AL-ZHGG-207.5-SYST'
          IF ( iener.EQ.31 ) sysname(1,nchan)='AL-ZHGG-208.-SYST'
          IF ( iener.EQ.32 ) sysname(1,nchan)='AL-ZHGG-208.5-SYST'
          IF ( iener.EQ.33 ) sysname(1,nchan)='AL-ZHGG-209.-SYST'
          IF ( iener.EQ.34 ) sysname(1,nchan)='AL-ZHGG-209.5-SYST'
          IF ( iener.EQ.35 ) sysname(1,nchan)='AL-ZHGG-210.-SYST'
C                 Relative error on signal efficiency = 5.2%/5.3% at y2k
            if ( ratech.ne.0 ) then
              if ( iener.GE.21 ) then
                dsig(1,nchan) = (ratech*0.053)/ratech
              else
                dsig(1,nchan) = (ratech*0.052)/ratech
              endif
            else
              dsig(1,nchan) = 0.
            endif
C                      Background shape
            call abhcreateB(xl,xu,nbinsint,a_zhgg_bkg_mass,
     &                  a_zhgg_bkg_n,0,0,a_hzgg_gsqrts(iener),
     &                  backw(nbins+1))
C                      No backround substraction
            call vzero(backg(nbins+1),nbinsint)
            dback(1,nchan) = 0.0
C                      Nb candidates
            nacand = A_ZHGG_NUMCAND(a_hzgg_gsqrts(iener))
            IF ( nacand.NE.0 ) THEN
              DO i = 1,nacand
                candmass = A_ZHGG_MASS_CAND(a_hzgg_gsqrts(iener),i) 
                call abin1(candmass,xl,xu,nbinsint,ibin)
                if (ibin.gt.0.and.ibin.le.nbinsint) then
                   ncand(nbins+ibin) = ncand(nbins+ibin) + 1
                endif
              ENDDO
            ENDIF
            ifirst(nchan) = nbins + 1
            nbins = nbins + nbinsint
          endif
        enddo
      endif
 
